@@ -121,9 +121,9 @@ generateRGB <- function(inputId, choices, selected, status, size, checkIcon) {
           htmltools::tags$input(
             type="radio", autocomplete="off",
             name=inputId, value=value,
-            checked=if (value %in% selected) "checked",
-            if (is.list(name)) name else htmltools::HTML(name)
-          )
+            checked=if (value %in% selected) "checked"
+          ),
+          if (is.list(name)) name else htmltools::HTML(name)
         )
       )
     },
@@ -222,10 +222,13 @@ updateRadioGroupButtons <- function(session, inputId, label = NULL, choices = NU
                                     status = "default", size = "normal",
                                     checkIcon = list(), choiceNames = NULL, choiceValues = NULL) {
   args <- normalizeChoicesArgs(choices, choiceNames, choiceValues, mustExist = FALSE)
-  if (is.null(selected) && !is.null(args$choiceValues))
+  if (is.null(selected) && !is.null(args$choiceValues)) {
     selected <- args$choiceValues[[1]]
+  } else {
+    selected <- as.character(selected)
+  }
   options <- if (!is.null(args$choiceValues)) {
-    format(htmltools::tagList(generateRGB(inputId, args, selected, status = status, size = size,
+    format(htmltools::tagList(generateRGB(session$ns(inputId), args, selected, status = status, size = size,
                                checkIcon = checkIcon)))
   }
   message <- dropNulls(list(selected = selected, options = options, label = label))
